summaryrefslogtreecommitdiff
path: root/src/com/android/dialer/filterednumber
diff options
context:
space:
mode:
Diffstat (limited to 'src/com/android/dialer/filterednumber')
-rw-r--r--src/com/android/dialer/filterednumber/BlockedNumbersMigrator.java121
-rw-r--r--src/com/android/dialer/filterednumber/MigrateBlockedNumbersDialogFragment.java35
2 files changed, 133 insertions, 23 deletions
diff --git a/src/com/android/dialer/filterednumber/BlockedNumbersMigrator.java b/src/com/android/dialer/filterednumber/BlockedNumbersMigrator.java
new file mode 100644
index 000000000..de201d98a
--- /dev/null
+++ b/src/com/android/dialer/filterednumber/BlockedNumbersMigrator.java
@@ -0,0 +1,121 @@
+/*
+ * Copyright (C) 2015 The Android Open Source Project
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ * http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
+
+package com.android.dialer.filterednumber;
+
+import com.google.common.base.Preconditions;
+
+import android.content.ContentResolver;
+import android.content.ContentValues;
+import android.database.Cursor;
+import android.os.AsyncTask;
+import android.support.annotation.Nullable;
+
+import com.android.dialer.compat.BlockedNumbersSdkCompat;
+import com.android.dialer.compat.FilteredNumberCompat;
+import com.android.dialer.database.FilteredNumberContract;
+import com.android.dialer.database.FilteredNumberContract.FilteredNumber;
+import com.android.dialer.database.FilteredNumberContract.FilteredNumberColumns;
+
+/**
+ * Class which should be used to migrate numbers from {@link FilteredNumberContract} blocking to
+ * {@link android.provider.BlockedNumberContract} blocking.
+ */
+public class BlockedNumbersMigrator {
+
+ /**
+ * Listener for the operation to migrate from {@link FilteredNumberContract} blocking to
+ * {@link android.provider.BlockedNumberContract} blocking.
+ */
+ public interface Listener {
+
+ /**
+ * Called when the migration operation is finished.
+ */
+ void onComplete();
+ }
+
+ private final ContentResolver mContentResolver;
+
+ /**
+ * Creates a new BlockedNumbersMigrate, using the given {@link ContentResolver} to perform
+ * queries against the blocked numbers tables.
+ *
+ * @param contentResolver The ContentResolver
+ * @throws NullPointerException if contentResolver is null
+ */
+ public BlockedNumbersMigrator(ContentResolver contentResolver) {
+ mContentResolver = Preconditions.checkNotNull(contentResolver);
+ }
+
+ /**
+ * Copies all of the numbers in the {@link FilteredNumberContract} block list to the
+ * {@link android.provider.BlockedNumberContract} block list.
+ *
+ * @param listener {@link Listener} called once the migration is complete.
+ * @return {@code true} if the migrate can be attempted, {@code false} otherwise.
+ * @throws NullPointerException if listener is null
+ */
+ public boolean migrate(final Listener listener) {
+ if (!FilteredNumberCompat.canUseNewFiltering()) {
+ return false;
+ }
+ Preconditions.checkNotNull(listener);
+ new AsyncTask<Void, Void, Boolean>() {
+ @Override
+ protected Boolean doInBackground(Void... params) {
+ return migrateToNewBlockingInBackground(mContentResolver);
+ }
+
+ @Override
+ protected void onPostExecute(Boolean isSuccessful) {
+ FilteredNumberCompat.setHasMigratedToNewBlocking(isSuccessful);
+ listener.onComplete();
+ }
+ }.execute();
+ return true;
+ }
+
+ private static boolean migrateToNewBlockingInBackground(ContentResolver resolver) {
+ try (Cursor cursor = resolver.query(FilteredNumber.CONTENT_URI,
+ new String[]{FilteredNumberColumns.NUMBER}, null, null, null)) {
+ if (cursor == null) {
+ return false;
+ }
+
+ while (cursor.moveToNext()) {
+ String originalNumber = cursor
+ .getString(cursor.getColumnIndex(FilteredNumberColumns.NUMBER));
+ if (isNumberInNewBlocking(resolver, originalNumber)) {
+ continue;
+ }
+ ContentValues values = new ContentValues();
+ values.put(BlockedNumbersSdkCompat.COLUMN_ORIGINAL_NUMBER, originalNumber);
+ resolver.insert(BlockedNumbersSdkCompat.CONTENT_URI, values);
+ }
+ return true;
+ }
+ }
+
+ private static boolean isNumberInNewBlocking(ContentResolver resolver, String originalNumber) {
+ try (Cursor cursor = resolver.query(BlockedNumbersSdkCompat.CONTENT_URI,
+ new String[]{BlockedNumbersSdkCompat._ID},
+ BlockedNumbersSdkCompat.COLUMN_ORIGINAL_NUMBER + " = ?",
+ new String[] {originalNumber}, null)) {
+ return cursor != null && cursor.getCount() != 0;
+ }
+ }
+}
diff --git a/src/com/android/dialer/filterednumber/MigrateBlockedNumbersDialogFragment.java b/src/com/android/dialer/filterednumber/MigrateBlockedNumbersDialogFragment.java
index 3783519e5..efcb50591 100644
--- a/src/com/android/dialer/filterednumber/MigrateBlockedNumbersDialogFragment.java
+++ b/src/com/android/dialer/filterednumber/MigrateBlockedNumbersDialogFragment.java
@@ -24,7 +24,6 @@ import android.app.DialogFragment;
import android.content.DialogInterface;
import android.content.DialogInterface.OnClickListener;
import android.os.Bundle;
-import android.support.annotation.Nullable;
import com.android.dialer.R;
@@ -34,31 +33,23 @@ import com.android.dialer.R;
*/
public class MigrateBlockedNumbersDialogFragment extends DialogFragment {
- /**
- * Listener for the operation to migrate from
- * {@link com.android.dialer.database.FilteredNumberContract} blocking to
- * {@link android.provider.BlockedNumberContract} blocking.
- */
- public interface Listener {
-
- /**
- * Callback called when the migration operation is finished.
- */
- void onComplete();
- }
-
- private Listener mMigrationListener;
+ private BlockedNumbersMigrator mBlockedNumbersMigrator;
+ private BlockedNumbersMigrator.Listener mMigrationListener;
/**
* Creates a new MigrateBlockedNumbersDialogFragment.
*
* @param migrationListener The {@link Listener} to call when the
* migration is complete.
* @return the new MigrateBlockedNumbersDialogFragment.
* @throws NullPointerException if migrationListener is {@code null}.
*/
- public static DialogFragment newInstance(Listener migrationListener) {
+ public static DialogFragment newInstance(BlockedNumbersMigrator blockedNumbersMigrator,
+ BlockedNumbersMigrator.Listener migrationListener) {
MigrateBlockedNumbersDialogFragment fragment = new MigrateBlockedNumbersDialogFragment();
+ fragment.mBlockedNumbersMigrator = Preconditions.checkNotNull(blockedNumbersMigrator);
fragment.mMigrationListener = Preconditions.checkNotNull(migrationListener);
return fragment;
}
@@ -79,10 +70,7 @@ public class MigrateBlockedNumbersDialogFragment extends DialogFragment {
return new OnClickListener() {
@Override
public void onClick(DialogInterface dialog, int which) {
- // TODO(maxwelb): Perform actual migration, call
- // FilteredNumberCompat#hasMigratedToNewBlocking
-
- mMigrationListener.onComplete();
+ mBlockedNumbersMigrator.migrate(mMigrationListener);
}
};
}
@@ -91,6 +79,7 @@ public class MigrateBlockedNumbersDialogFragment extends DialogFragment {
public void onPause() {
// The dialog is dismissed and state is cleaned up onPause, i.e. rotation.
dismiss();
+ mBlockedNumbersMigrator = null;
mMigrationListener = null;
super.onPause();
}
@@ -34,31 +33,23 @@ import com.android.dialer.R;
* Creates a new MigrateBlockedNumbersDialogFragment.
*
- * @param migrationListener The {@link Listener} to call when the
+ * @param blockedNumbersMigrator The {@link BlockedNumbersMigrator} which will be used to
+ * migrate the numbers.
+ * @param migrationListener The {@link BlockedNumbersMigrator.Listener} to call when the
* migration is complete.
@@ -34,31 +33,23 @@ import com.android.dialer.R;
* migration is complete.
- * @return the new MigrateBlockedNumbersDialogFragment.
- * @throws NullPointerException if migrationListener is {@code null}.
+ * @return The new MigrateBlockedNumbersDialogFragment.
+ * @throws NullPointerException if blockedNumbersMigrator or migrationListener are {@code null}.
*/